==> jc-1.4.0.tar.gz: polyglot/lex/StringLiteral.h <==
// public class polyglot.lex.StringLiteral

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 923d72acc1d3eef7 polyglot_lex_Literal
// @dep_class 6e328734d0b6f7f5 polyglot_lex_StringLiteral
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_Literal

#include "polyglot/lex/Literal.h"

#ifndef _JC_polyglot_lex_StringLiteral_H_
#define _JC_polyglot_lex_StringLiteral_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_StringLiteral$sub_refs	_jc_polyglot_lex_StringLiteral$sub_refs;
typedef struct _jc_polyglot_lex_StringLiteral$sub_nonrefs	_jc_polyglot_lex_StringLiteral$sub_nonrefs;
typedef struct _jc_polyglot_lex_StringLiteral$refs	_jc_polyglot_lex_StringLiteral$refs;
typedef struct _jc_polyglot_lex_StringLiteral$nonrefs	_jc_polyglot_lex_StringLiteral$nonrefs;
typedef struct _jc_polyglot_lex_StringLiteral$object	_jc_polyglot_lex_StringLiteral$object;

typedef const struct _jc_polyglot_lex_StringLiteral$vmethods	_jc_polyglot_lex_StringLiteral$vmethods;
typedef const struct _jc_polyglot_lex_StringLiteral$vtable	_jc_polyglot_lex_StringLiteral$vtable;
typedef const struct _jc_polyglot_lex_StringLiteral$vtype	_jc_polyglot_lex_StringLiteral$vtype;

// Constructors
extern void _jc_polyglot_lex_StringLiteral$method$_init$37e74d0be0d3e539(_jc_env *, struct _jc_polyglot_lex_StringLiteral$object *, struct _jc_polyglot_util_Position$object *, struct _jc_java_lang_String$object *, jint);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_lex_StringLiteral$method$getValue$70c0a0897e30f88c(_jc_env *, struct _jc_polyglot_lex_StringLiteral$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_lex_StringLiteral$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_lex_StringLiteral$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_lex_StringLiteral$method_info$getValue$70c0a0897e30f88c;
extern _jc_method _jc_polyglot_lex_StringLiteral$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_lex_StringLiteral$vmethods {
	struct _jc_java_lang_String$object	*(*getValue$70c0a0897e30f88c)(_jc_env *, struct _jc_polyglot_lex_StringLiteral$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_lex_StringLiteral$object *);
};

// Vtable
struct _jc_polyglot_lex_StringLiteral$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_lex_Literal$vmethods	polyglot_lex_Literal;
	_jc_polyglot_lex_StringLiteral$vmethods	polyglot_lex_StringLiteral;
};

// Vtype
struct _jc_polyglot_lex_StringLiteral$vtype {
	_jc_type			type;
	_jc_polyglot_lex_StringLiteral$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_StringLiteral$sub_refs {
	struct _jc_java_lang_String$object	*val;
};

// Reference instance fields (object)
struct _jc_polyglot_lex_StringLiteral$refs {
    _jc_polyglot_lex_StringLiteral$sub_refs	polyglot_lex_StringLiteral;
    _jc_polyglot_lex_Literal$sub_refs	polyglot_lex_Literal;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_StringLiteral$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_StringLiteral$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_lex_Literal$sub_nonrefs	polyglot_lex_Literal;
    _jc_polyglot_lex_StringLiteral$sub_nonrefs	polyglot_lex_StringLiteral;
};

// Object instance structure
struct _jc_polyglot_lex_StringLiteral$object {
	_jc_polyglot_lex_StringLiteral$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_StringLiteral$vtype	*vtype;
	_jc_polyglot_lex_StringLiteral$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_StringLiteral$vtype _jc_polyglot_lex_StringLiteral$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_StringLiteral, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_StringLiteral$class_object;

#endif	/* _JC_polyglot_lex_StringLiteral_H_ */

==> jc-1.4.6.tar.gz: polyglot/lex/StringLiteral.h <==
// public class polyglot.lex.StringLiteral

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 923d72acc1d3eef7 polyglot_lex_Literal
// @dep_class 6e328734d0b6f7f5 polyglot_lex_StringLiteral
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_Literal

#include "polyglot/lex/Literal.h"

#ifndef _JC_polyglot_lex_StringLiteral_H_
#define _JC_polyglot_lex_StringLiteral_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_StringLiteral$sub_refs	_jc_polyglot_lex_StringLiteral$sub_refs;
typedef struct _jc_polyglot_lex_StringLiteral$sub_nonrefs	_jc_polyglot_lex_StringLiteral$sub_nonrefs;
typedef struct _jc_polyglot_lex_StringLiteral$refs	_jc_polyglot_lex_StringLiteral$refs;
typedef struct _jc_polyglot_lex_StringLiteral$nonrefs	_jc_polyglot_lex_StringLiteral$nonrefs;
typedef struct _jc_polyglot_lex_StringLiteral$object	_jc_polyglot_lex_StringLiteral$object;

typedef const struct _jc_polyglot_lex_StringLiteral$vmethods	_jc_polyglot_lex_StringLiteral$vmethods;
typedef const struct _jc_polyglot_lex_StringLiteral$vtable	_jc_polyglot_lex_StringLiteral$vtable;
typedef const struct _jc_polyglot_lex_StringLiteral$vtype	_jc_polyglot_lex_StringLiteral$vtype;

// Constructors
extern void _jc_polyglot_lex_StringLiteral$method$_init$37e74d0be0d3e539(_jc_env *, struct _jc_polyglot_lex_StringLiteral$object *, struct _jc_polyglot_util_Position$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_polyglot_lex_StringLiteral$method$getValue$70c0a0897e30f88c(_jc_env *, struct _jc_polyglot_lex_StringLiteral$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_lex_StringLiteral$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_lex_StringLiteral$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_lex_StringLiteral$method_info$getValue$70c0a0897e30f88c;
extern _jc_method _jc_polyglot_lex_StringLiteral$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_lex_StringLiteral$vmethods {
	struct _jc_java_lang_String$object	*(*getValue$70c0a0897e30f88c)(_jc_env *, struct _jc_polyglot_lex_StringLiteral$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_lex_StringLiteral$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_lex_StringLiteral$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_lex_Literal$vmethods	polyglot_lex_Literal;
	_jc_polyglot_lex_StringLiteral$vmethods	polyglot_lex_StringLiteral;
};

// Vtype
struct _jc_polyglot_lex_StringLiteral$vtype {
	_jc_type			type;
	_jc_polyglot_lex_StringLiteral$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_StringLiteral$sub_refs {
	struct _jc_java_lang_String$object	*val;
};

// Reference instance fields (object)
struct _jc_polyglot_lex_StringLiteral$refs {
    _jc_polyglot_lex_StringLiteral$sub_refs	polyglot_lex_StringLiteral;
    _jc_polyglot_lex_Literal$sub_refs	polyglot_lex_Literal;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_StringLiteral$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_StringLiteral$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_lex_Literal$sub_nonrefs	polyglot_lex_Literal;
    _jc_polyglot_lex_StringLiteral$sub_nonrefs	polyglot_lex_StringLiteral;
};

// Object instance structure
struct _jc_polyglot_lex_StringLiteral$object {
	_jc_polyglot_lex_StringLiteral$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_StringLiteral$vtype	*vtype;
	_jc_polyglot_lex_StringLiteral$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_StringLiteral$vtype _jc_polyglot_lex_StringLiteral$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_StringLiteral, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_StringLiteral$class_object;

#endif	/* _JC_polyglot_lex_StringLiteral_H_ */
